@@ -3,6 +3,7 @@
 import json
 
 from jwt.exceptions import (
+    KeyNotFound,
     MalformedJWT,
     UnsupportedAlgorithm,
 )
@@ -30,6 +31,9 @@ class JWT(Impl):
 
         raise UnsupportedAlgorithm(alg)
 
+    def sign(self, alg, message, kid=None):
+        return self.jws.sign(alg, message, kid)
+
     def verify(self, jwt):
         assert isinstance(jwt, str)
 
